==> jc-1.4.0.tar.gz: java/util/TreeMap__24TreeIterator.h <==
// final class java.util.TreeMap$TreeIterator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9ade8df06f343d57 java_util_TreeMap__24TreeIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_TreeMap__24TreeIterator_H_
#define _JC_java_util_TreeMap__24TreeIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_TreeMap$object;
struct _jc_java_util_TreeMap__24Node$object;

// Typedefs
typedef struct _jc_java_util_TreeMap__24TreeIterator$sub_refs	_jc_java_util_TreeMap__24TreeIterator$sub_refs;
typedef struct _jc_java_util_TreeMap__24TreeIterator$sub_nonrefs	_jc_java_util_TreeMap__24TreeIterator$sub_nonrefs;
typedef struct _jc_java_util_TreeMap__24TreeIterator$refs	_jc_java_util_TreeMap__24TreeIterator$refs;
typedef struct _jc_java_util_TreeMap__24TreeIterator$nonrefs	_jc_java_util_TreeMap__24TreeIterator$nonrefs;
typedef struct _jc_java_util_TreeMap__24TreeIterator$object	_jc_java_util_TreeMap__24TreeIterator$object;

typedef const struct _jc_java_util_TreeMap__24TreeIterator$vmethods	_jc_java_util_TreeMap__24TreeIterator$vmethods;
typedef const struct _jc_java_util_TreeMap__24TreeIterator$vtable	_jc_java_util_TreeMap__24TreeIterator$vtable;
typedef const struct _jc_java_util_TreeMap__24TreeIterator$vtype	_jc_java_util_TreeMap__24TreeIterator$vtype;

// Constructors
extern void _jc_java_util_TreeMap__24TreeIterator$method$_init$e5cf9b921ff0d809(_jc_env *, struct _jc_java_util_TreeMap__24TreeIterator$object *, struct _jc_java_util_TreeMap$object *, jint);
extern void _jc_java_util_TreeMap__24TreeIterator$method$_init$db907761a1142845(_jc_env *, struct _jc_java_util_TreeMap__24TreeIterator$object *, struct _jc_java_util_TreeMap$object *, jint, struct _jc_java_util_TreeMap__24Node$object *, struct _jc_java_util_TreeMap__24Node$object *);

// Virtual methods
extern jboolean _jc_java_util_TreeMap__24TreeIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_java_util_TreeMap__24TreeIterator$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_TreeMap__24TreeIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_java_util_TreeMap__24TreeIterator$object *);
extern void _jc_java_util_TreeMap__24TreeIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_java_util_TreeMap__24TreeIterator$object *);
extern void _jc_java_util_TreeMap__24TreeIterator$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_util_TreeMap__24TreeIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_TreeMap__24TreeIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_java_util_TreeMap__24TreeIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_java_util_TreeMap__24TreeIterator$method_info$remove$fd50149979e1f350;
extern _jc_method _jc_java_util_TreeMap__24TreeIterator$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_util_TreeMap__24TreeIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_java_util_TreeMap__24TreeIterator$object *);
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_java_util_TreeMap__24TreeIterator$object *);
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_java_util_TreeMap__24TreeIterator$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_util_TreeMap__24TreeIterator$object *);
};

// Vtable
struct _jc_java_util_TreeMap__24TreeIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_TreeMap__24TreeIterator$vmethods	java_util_TreeMap__24TreeIterator;
};

// Vtype
struct _jc_java_util_TreeMap__24TreeIterator$vtype {
	_jc_type			type;
	_jc_java_util_TreeMap__24TreeIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_TreeMap__24TreeIterator$sub_refs {
	struct _jc_java_util_TreeMap__24Node$object	*last;
	struct _jc_java_util_TreeMap__24Node$object	*next;
	struct _jc_java_util_TreeMap__24Node$object	*max;
	struct _jc_java_util_TreeMap$object	*this;
};

// Reference instance fields (object)
struct _jc_java_util_TreeMap__24TreeIterator$refs {
    _jc_java_util_TreeMap__24TreeIterator$sub_refs	java_util_TreeMap__24TreeIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_TreeMap__24TreeIterator$sub_nonrefs {
	jint	type;
	jint	knownMod;
};

// Non-reference instance fields (object)
struct _jc_java_util_TreeMap__24TreeIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_TreeMap__24TreeIterator$sub_nonrefs	java_util_TreeMap__24TreeIterator;
};

// Object instance structure
struct _jc_java_util_TreeMap__24TreeIterator$object {
	_jc_java_util_TreeMap__24TreeIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_TreeMap__24TreeIterator$vtype	*vtype;
	_jc_java_util_TreeMap__24TreeIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_TreeMap__24TreeIterator$vtype _jc_java_util_TreeMap__24TreeIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_TreeMap__24TreeIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_TreeMap__24TreeIterator$class_object;

#endif	/* _JC_java_util_TreeMap__24TreeIterator_H_ */

==> jc-1.4.6.tar.gz: java/util/TreeMap__24TreeIterator.h <==
// final class java.util.TreeMap$TreeIterator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9ade8df06f343d57 java_util_TreeMap__24TreeIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_TreeMap__24TreeIterator_H_
#define _JC_java_util_TreeMap__24TreeIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_TreeMap$object;
struct _jc_java_util_TreeMap__24Node$object;

// Typedefs
typedef struct _jc_java_util_TreeMap__24TreeIterator$sub_refs	_jc_java_util_TreeMap__24TreeIterator$sub_refs;
typedef struct _jc_java_util_TreeMap__24TreeIterator$sub_nonrefs	_jc_java_util_TreeMap__24TreeIterator$sub_nonrefs;
typedef struct _jc_java_util_TreeMap__24TreeIterator$refs	_jc_java_util_TreeMap__24TreeIterator$refs;
typedef struct _jc_java_util_TreeMap__24TreeIterator$nonrefs	_jc_java_util_TreeMap__24TreeIterator$nonrefs;
typedef struct _jc_java_util_TreeMap__24TreeIterator$object	_jc_java_util_TreeMap__24TreeIterator$object;

typedef const struct _jc_java_util_TreeMap__24TreeIterator$vmethods	_jc_java_util_TreeMap__24TreeIterator$vmethods;
typedef const struct _jc_java_util_TreeMap__24TreeIterator$vtable	_jc_java_util_TreeMap__24TreeIterator$vtable;
typedef const struct _jc_java_util_TreeMap__24TreeIterator$vtype	_jc_java_util_TreeMap__24TreeIterator$vtype;

// Constructors
extern void _jc_java_util_TreeMap__24TreeIterator$method$_init$e5cf9b921ff0d809(_jc_env *, struct _jc_java_util_TreeMap__24TreeIterator$object *, struct _jc_java_util_TreeMap$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_util_TreeMap__24TreeIterator$method$_init$db907761a1142845(_jc_env *, struct _jc_java_util_TreeMap__24TreeIterator$object *, struct _jc_java_util_TreeMap$object *, jint, struct _jc_java_util_TreeMap__24Node$object *, struct _jc_java_util_TreeMap__24Node$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_util_TreeMap__24TreeIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_java_util_TreeMap__24TreeIterator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_TreeMap__24TreeIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_java_util_TreeMap__24TreeIterator$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_TreeMap__24TreeIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_java_util_TreeMap__24TreeIterator$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_TreeMap__24TreeIterator$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_util_TreeMap__24TreeIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_TreeMap__24TreeIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_java_util_TreeMap__24TreeIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_java_util_TreeMap__24TreeIterator$method_info$remove$fd50149979e1f350;
extern _jc_method _jc_java_util_TreeMap__24TreeIterator$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_util_TreeMap__24TreeIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_java_util_TreeMap__24TreeIterator$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_java_util_TreeMap__24TreeIterator$object *) _JC_JCNI_ATTR;
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_java_util_TreeMap__24TreeIterator$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_util_TreeMap__24TreeIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_TreeMap__24TreeIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_TreeMap__24TreeIterator$vmethods	java_util_TreeMap__24TreeIterator;
};

// Vtype
struct _jc_java_util_TreeMap__24TreeIterator$vtype {
	_jc_type			type;
	_jc_java_util_TreeMap__24TreeIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_TreeMap__24TreeIterator$sub_refs {
	struct _jc_java_util_TreeMap__24Node$object	*last;
	struct _jc_java_util_TreeMap__24Node$object	*next;
	struct _jc_java_util_TreeMap__24Node$object	*max;
	struct _jc_java_util_TreeMap$object	*this;
};

// Reference instance fields (object)
struct _jc_java_util_TreeMap__24TreeIterator$refs {
    _jc_java_util_TreeMap__24TreeIterator$sub_refs	java_util_TreeMap__24TreeIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_TreeMap__24TreeIterator$sub_nonrefs {
	jint	type;
	jint	knownMod;
};

// Non-reference instance fields (object)
struct _jc_java_util_TreeMap__24TreeIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_TreeMap__24TreeIterator$sub_nonrefs	java_util_TreeMap__24TreeIterator;
};

// Object instance structure
struct _jc_java_util_TreeMap__24TreeIterator$object {
	_jc_java_util_TreeMap__24TreeIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_TreeMap__24TreeIterator$vtype	*vtype;
	_jc_java_util_TreeMap__24TreeIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_TreeMap__24TreeIterator$vtype _jc_java_util_TreeMap__24TreeIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_TreeMap__24TreeIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_TreeMap__24TreeIterator$class_object;

#endif	/* _JC_java_util_TreeMap__24TreeIterator_H_ */
